"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.camelcase2Line = exports.line2Camelcase = exports.html2Escape = exports.toHtml = exports.spaceToHtml = exports.lineToHtml = exports.toCDB = exports.toDBC = exports.trim = exports.slice = exports.translateObj = exports.formatKey = exports.format = void 0;

/**
 * 字符串替换占位符
 * 如：format('http://{0}/{1}', "www.huayun.com", "index.html")
 */
var format = function format(string) {
  if (string) {
    if ((arguments.length <= 1 ? 0 : arguments.length - 1) === 0) return string;
    var len = arguments.length <= 1 ? 0 : arguments.length - 1;

    for (var i = 0; i < len; i++) {
      string = string.replace(new RegExp("\\{".concat(i, "\\}"), 'g'), i + 1 < 1 || arguments.length <= i + 1 ? undefined : arguments[i + 1]);
    }

    return string;
  }

  return '';
};
/**
 * 字符串替换占位符，字典方式
 * 如：formatKey('云主机{name}创建成功', {name: '测试机'})
 */


exports.format = format;

var formatKey = function formatKey(string, data) {
  if (string) {
    var keys = Object.keys(data);
    keys.map(function (key) {
      string = string.replace(new RegExp("\\{".concat(key, "\\}"), 'g'), data[key]);
    });
    return string;
  }

  return '';
};
/**
 * 翻译结构体
 * @param {object || string} obj 可翻译结构体 或者 字符串，格式如：{code: 50001, context: {name: 'xxx'}} 或者 50001
 * @return {string} 翻译过的文本
 */


exports.formatKey = formatKey;

var translateObj = function translateObj(obj) {
  var string = '';

  if (obj && window.LanguageData) {
    if (window._.isString(obj)) {
      string = window.LanguageData[window.LangCode][obj] || obj;
    } else if (window._.isObject(obj) && obj.code) {
      string = window.LanguageData[window.LangCode][parseInt(obj.code)] || obj.code;

      if (obj.context && !window._.isNumber(string)) {
        string = formatKey(string, obj.context);
      }
    }

    return string;
  }

  return string;
};
/**
 * 截取字符串，如果长度大于截取长度，接省略号
 * @param  {string} string 源字符串
 * @param  {int} start  开始位置
 * @param  {int} end    结束位置
 * @param  {String} fill   补充字符
 * @return {string}        截取后字符串
 */


exports.translateObj = translateObj;

var slice = function slice(string, start, end) {
  var fill = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : '...';
  var result = string.slice(start, end);

  if (fill && string.length > end) {
    result = "".concat(result).concat(fill);
  }

  return result;
};
/**
 * 去前后空格
 */


exports.slice = slice;

var trim = function trim(string) {
  return string.replace(/(^\s*)|(\s*$)/g, '');
};
/**
 * 符号半角转全角
 * @param  {string} string 要转换的字符串
 * @return {string}
 */


exports.trim = trim;

var toDBC = function toDBC(str) {
  var result = '';
  var len = str.length;

  for (var i = 0; i < len; i++) {
    var cCode = str.charCodeAt(i); // 全角与半角相差（除空格外）：65248(十进制)

    cCode = cCode >= 0x0021 && cCode <= 0x007E ? cCode + 65248 : cCode; // 处理空格

    cCode = cCode === 0x0020 ? 0x03000 : cCode;
    result += String.fromCharCode(cCode);
  }

  return result;
};
/**
 * 全角转半角
 * @param  {string} string
 * @return {string}
 */


exports.toDBC = toDBC;

var toCDB = function toCDB(str) {
  var result = '';
  var len = str.length;

  for (var i = 0; i < len; i++) {
    var cCode = str.charCodeAt(i); // 全角与半角相差（除空格外）：65248（十进制）

    cCode = cCode >= 0xFF01 && cCode <= 0xFF5E ? cCode - 65248 : cCode; // 处理空格

    cCode = cCode === 0x03000 ? 0x0020 : cCode;
    result += String.fromCharCode(cCode);
  }

  return result;
};
/**
 * 转换所有换行符为<br />
 * @param  {string} string 字符串
 * @return {string}
 */


exports.toCDB = toCDB;

var lineToHtml = function lineToHtml(string) {
  if (string) {
    string = string.replace(/\r\n/g, '<br>');
    string = string.replace(/\n/g, '<br>');
    return string;
  }

  return '';
};
/**
 * 转换所有空格符为&nbsp;
 * @param  {string} string 字符串
 * @return {string}
 */


exports.lineToHtml = lineToHtml;

var spaceToHtml = function spaceToHtml(string) {
  if (string) {
    string = string.replace(/\s/g, '&nbsp;');
    return string;
  }

  return '';
};
/**
 * 转换所有换行空格符
 * @param  {string} string 字符串
 * @return {string}
 */


exports.spaceToHtml = spaceToHtml;

var toHtml = function toHtml(string) {
  if (string) {
    return spaceToHtml(lineToHtml(string));
  }

  return '';
};
/**
 * 转译html标签
 * @param  {string} sHtml
 * @return {string}
 */


exports.toHtml = toHtml;

var html2Escape = function html2Escape(sHtml) {
  if (sHtml) {
    return sHtml.replace(/[<>&"]/g, function (c) {
      return {
        '<': '&lt;',
        '>': '&gt;',
        '&': '&amp;',
        '"': '&quot;'
      }[c];
    });
  }

  return '';
};
/**
 * 下划线书写转驼峰，如 vm_id => vmId
 * @param  {string} string
 * @return {string}
 */


exports.html2Escape = html2Escape;

var line2Camelcase = function line2Camelcase(string) {
  if (string) {
    var re = /_(\w)/g;
    return string.replace(re, function ($0, $1) {
      return $1.toUpperCase();
    });
  }

  return '';
};
/**
 * 驼峰转下划线书写，如 vmId => vm_id
 * @param  {string} string
 * @return {string}
 */


exports.line2Camelcase = line2Camelcase;

var camelcase2Line = function camelcase2Line(string) {
  if (string) {
    return string.replace(/([A-Z])/g, '_$1').toLowerCase();
  }

  return '';
};

exports.camelcase2Line = camelcase2Line;